# Downloaded Documentation

This directory contains downloaded documentation files from the libraries used in the Knowledge Graph implementation.

## Files

### vis.js Network Documentation
- `vis-network-configure.html` - Configuration options
- `vis-network-edges.html` - Edge configuration and styling
- `vis-network-nodes.html` - Node configuration and styling
- `vis-network-physics.html` - Physics simulation options
- `vis-network-interaction.html` - User interaction settings
- `vis-network-layout.html` - Layout algorithms
- `vis-network-readme.md` - Repository README

### html2canvas Documentation
- `html2canvas-configuration.md` - Configuration options
- `html2canvas-documentation.md` - Main documentation
- `html2canvas-faq.md` - Frequently asked questions
- `html2canvas-features.md` - Feature list
- `html2canvas-getting-started.md` - Getting started guide
- `html2canvas-proxy.md` - Proxy configuration
- `html2canvas-readme.md` - Repository README

### JetBrains Mono Font
- `jetbrains-mono-readme.md` - Font repository README

## Source Repositories

- **vis-network:** https://github.com/visjs/vis-network
- **html2canvas:** https://github.com/niklasvh/html2canvas
- **JetBrains Mono:** https://github.com/JetBrains/JetBrainsMono

## Last Updated

Documentation files downloaded on: 2025-01-15

## Note

These files are downloaded from the official GitHub repositories for offline reference. For the most up-to-date documentation, please visit the official documentation websites:

- vis-network: https://visjs.github.io/vis-network/docs/network/
- html2canvas: https://html2canvas.hertzen.com/











